==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/systemtags/l10n/uk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Назва тегу порожня",
    "Update" : "Оновити",
    "Create" : "Створити",
    "Select tag …" : "Виберіть тег…",
    "System tag %1$s added by the system" : "Системний тег %1$s , доданий системою",
    "Added system tag {systemtag}" : "Додано системний тег {systemtag}",
    "Added system tag %1$s" : "Додано системний тег %1$s",
    "%1$s added system tag %2$s" : "%1$s доданий системний тег %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додав системний тег {systemtag}",
    "System tag %1$s removed by the system" : "Системний тег %1$s видалено системою",
    "Removed system tag {systemtag}" : "Видалено системний тег {systemtag}",
    "Removed system tag %1$s" : "Видалено системний тег %1$s",
    "%1$s removed system tag %2$s" : "%1$s видалений системний тег %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} видалив системний тег {systemtag}",
    "You created system tag %1$s" : "Ви створили системний тег %1$s",
    "You created system tag {systemtag}" : "Ви створили системний тег {systemtag}",
    "%1$s created system tag %2$s" : "%1$s створений системний тег %2$s ",
    "{actor} created system tag {systemtag}" : "{actor} створив системний тег {systemtag}",
    "You deleted system tag %1$s" : "Ви видалили системний тег %1$s",
    "You deleted system tag {systemtag}" : "Ви видалили системний тег {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s вилучена системна мітка %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} видалив системний тег {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ви оновили системний тег %2$s до %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ви оновили системний тег {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s оновлено системний тег %3$s до %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} оновив системний тег {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системний тег %2$s додано до %1$s системою",
    "System tag {systemtag} was added to {file} by the system" : "Системний тег {systemtag} додано до {file} системою",
    "You added system tag %2$s to %1$s" : "Ви додали системний тег %2$s до %1$s",
    "You added system tag {systemtag} to {file}" : "Ви додали системний тег {systemtag} до {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додано системний тег %3$s до %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додав системний тег {systemtag} до {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системний тег %2$s видалено з %1$s системою",
    "System tag {systemtag} was removed from {file} by the system" : "Системний тег {systemtag} видалено з {file} системою",
    "You removed system tag %2$s from %1$s" : "Ви видалили системний тег %2$s із %1$s",
    "You removed system tag {systemtag} from {file}" : "Ви видалили системний тег {systemtag} із {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s видалено системний тег %3$s з %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} видалив системний тег {systemtag} із {file}",
    "%s (restricted)" : "%s(обмежено)",
    "%s (invisible)" : "%s (невидимий)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>системні позначки</strong>для файлу було змінено",
    "Tags" : "Позначки",
    "All tagged %s …" : "Усі позначені тегами %s …",
    "tagged %s" : "позначений тегами %s",
    "Collaborative tags" : "Позначки для співпраці",
    "Collaborative tagging functionality which shares tags among users." : "Функція спільного додавання тегів, яка ділиться тегами між користувачами.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функція спільного додавання тегів, яка ділиться тегами між користувачами. Чудово підходить для команд. \n(Якщо ви є провайдером із установкою з кількома клієнтами, радимо вимкнути цю програму, оскільки теги є спільними.)",
    "Tagged files" : "Файли з позначками",
    "Select tags to filter by" : "Фільтр вибору позначок за",
    "No tags found" : "Не знайдено позначок",
    "Please select tags to filter by" : "Будь ласка, виберіть позначки, відібрані за",
    "No files found for the selected tags" : "Не знайдено файлів із вибраними позначками",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Спільні теги доступні для всіх користувачів. Заборонені теги видимі для користувачів, але вони не можуть їх призначити. Невидимі теги призначені для внутрішнього використання, оскільки користувачі не можуть бачити або призначати їх.",
    "Create a new tag" : "Створити нову позначку",
    "Name" : "Ім’я",
    "Public" : "Публічна",
    "Restricted" : "Обмежена",
    "Invisible" : "Невидима",
    "Delete" : "Вилучити",
    "Reset" : "Скидання",
    "No files in here" : "Тут немає файлів",
    "No entries found in this folder" : "В цьому каталозі нічого немає",
    "Size" : "Розмір",
    "Modified" : "Змінено"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-24.0.7.tar.bz2: nextcloud/apps/systemtags/l10n/uk.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tag name is empty" : "Назва тегу порожня",
    "Update" : "Оновити",
    "Create" : "Створити",
    "Select tag …" : "Виберіть тег…",
    "System tag %1$s added by the system" : "Системний тег %1$s , доданий системою",
    "Added system tag {systemtag}" : "Додано системний тег {systemtag}",
    "Added system tag %1$s" : "Додано системний тег %1$s",
    "%1$s added system tag %2$s" : "%1$s доданий системний тег %2$s",
    "{actor} added system tag {systemtag}" : "{actor} додав системний тег {systemtag}",
    "System tag %1$s removed by the system" : "Системну мітку %1$s вилучено системою",
    "Removed system tag {systemtag}" : "Вилучено системну мітку {systemtag}",
    "Removed system tag %1$s" : "Вилучено системну мітку %1$s",
    "%1$s removed system tag %2$s" : "%1$s вилучив системну мітку %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} вилучив системну мітку {systemtag}",
    "You created system tag %1$s" : "Ви створили системний тег %1$s",
    "You created system tag {systemtag}" : "Ви створили системний тег {systemtag}",
    "%1$s created system tag %2$s" : "%1$s створений системний тег %2$s ",
    "{actor} created system tag {systemtag}" : "{actor} створив системний тег {systemtag}",
    "You deleted system tag %1$s" : "Ви вилучили системну мітку %1$s",
    "You deleted system tag {systemtag}" : "Ви вилучили системний тег {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s вилучена системна мітка %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} вилучив системну мітку {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ви оновили системний тег %2$s до %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ви оновили системний тег {oldsystemtag} на {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s оновлено системний тег %3$s до %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} оновив системний тег {oldsystemtag} на {newsystemtag}",
    "System tag %2$s was added to %1$s by the system" : "Системний тег %2$s додано до %1$s системою",
    "System tag {systemtag} was added to {file} by the system" : "Системний тег {systemtag} додано до {file} системою",
    "You added system tag %2$s to %1$s" : "Ви додали системний тег %2$s до %1$s",
    "You added system tag {systemtag} to {file}" : "Ви додали системний тег {systemtag} до {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s додано системний тег %3$s до %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} додав системний тег {systemtag} до {file}",
    "System tag %2$s was removed from %1$s by the system" : "Системну мітку %2$s вилучено системою з %1$s",
    "System tag {systemtag} was removed from {file} by the system" : "Системну мітку {systemtag} вилучено системою з файлу {file}",
    "You removed system tag %2$s from %1$s" : "Ви вилучили системну мітку %2$s із %1$s",
    "You removed system tag {systemtag} from {file}" : "Ви вилучили системну мітку {systemtag} із {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s вилучено системну мітку %3$s з %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} вилучив системну мітку {systemtag} із {file}",
    "%s (restricted)" : "%s(обмежено)",
    "%s (invisible)" : "%s (невидимий)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>системні позначки</strong>для файлу було змінено",
    "Tags" : "Позначки",
    "All tagged %s …" : "Усі позначені тегами %s …",
    "tagged %s" : "позначений тегами %s",
    "Collaborative tags" : "Позначки для співпраці",
    "Collaborative tagging functionality which shares tags among users." : "Функція спільного додавання тегів, яка ділиться тегами між користувачами.",
    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Функція спільного додавання тегів, яка ділиться тегами між користувачами. Чудово підходить для команд. \n(Якщо ви є провайдером із установкою з кількома клієнтами, радимо вимкнути цю програму, оскільки теги є спільними.)",
    "Tagged files" : "Файли з позначками",
    "Select tags to filter by" : "Фільтр вибору позначок за",
    "No tags found" : "Не знайдено позначок",
    "Please select tags to filter by" : "Будь ласка, виберіть позначки, відібрані за",
    "No files found for the selected tags" : "Не знайдено файлів із вибраними позначками",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Спільні теги доступні для всіх користувачів. Заборонені теги видимі для користувачів, але вони не можуть їх призначити. Невидимі теги призначені для внутрішнього використання, оскільки користувачі не можуть бачити або призначати їх.",
    "Create a new tag" : "Створити нову позначку",
    "Name" : "Ім’я",
    "Public" : "Публічна",
    "Restricted" : "Обмежена",
    "Invisible" : "Невидима",
    "Delete" : "Вилучити",
    "Reset" : "Скидання",
    "No files in here" : "Тут немає файлів",
    "No entries found in this folder" : "В цьому каталозі нічого немає",
    "Size" : "Розмір",
    "Modified" : "Змінено"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
